@@ -29,11 +29,12 @@ foreach $f (split(/\000/, $makefiles)) {
   while (<F>) {
     #print ">> $_";
     chomp;
-    if (/^obj\-\$\((CONFIG_.+?)\)\s+\+?=\s+(.*)$/) {
-    # matches:  obj-$(CONFIG_AZTCD)             += aztcd.o
+    if (/^obj\-\$\((CONFIG_.+?)\)\s+\+?=\s+([^#]*).*$/) {
+    # matches:  obj-$(CONFIG_AZTCD)             += aztcd.o # comment
       my $cfg = $1;
       foreach (split(/\s+/,$2)) {
-        push(@{$objs{$cfg}},$_);
+        push(@{$objs{$cfg}},$_) if ($_ !~ /[\$\\]/);
+	# DEBUG printf "%s - %s\n", $cfg, $_ if ($_ !~ /[\$\\]/);
       }
       $lastline = $_;
       next;
@@ -63,14 +64,15 @@ while (<H>) {
   }
 
   $lastline = $_;
-  $lastline=~s/"/\\"/g;
+  $lastline=~s/`/'/g;
+  $lastline=~s/"/'/g;
 }
 close H;
 
 sub xlat_objname {
   my $obj = shift;
 
-  $obj =~ s/\.o$//;
+  $obj =~ s/\.[co]$//;
   $obj =~ s/[-,\+]/_/g;
   $obj =~ s/.*\/(.+)/$1/;
   return "summary_$obj";
